@@ -160,6 +160,7 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
         #self.show_find_results
 
         self.make_drawing = 1
+        self.gdkdrawable = None
 
     def do_draw(self, gpsmap, gdkdrawable):
         #return None
@@ -173,6 +174,7 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
             x = self.size[0]-64
 
             cr = gdkdrawable.cairo_create()
+            self.gdkdrawable = gdkdrawable
 
             cr.set_source_surface( self.pb_plus, x,10 )
             cr.paint()
@@ -323,46 +325,66 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
             x = gdkeventbutton.x
             y = gdkeventbutton.y
             print "click at :",x,",",y
+
+
+            for c in self.osmMapa.clikable_icons:
+                if x >= c[0] and y >= c[1] and x<= c[2] and y<= c[3]:
+                    self.osmMapa.cliked_item = [ c[4][0],c[4][1] ]
+                    self.osmMapa.set_gpslock( False )
+                    if self.osmMapa.cliked_item <> []:
+                        self.osmMapa.osm.set_center( c[4][0], c[4][1] )
+                    else:
+                        cr = self.gdkdrawable.cairo_create()
+                        self.osmMapa.draw_cloud_byll(cr, c[4])
+                    
+
+
             for c in self.osmMapa.clikable_clouds:
                 if x >= c[0] and y >= c[1] and x<= c[2] and y<= c[3]:
-                    print "c:",c
-                    m = gtk.Menu()
-                    latc,lonc = self.osmMapa.get_may_current_ll()
-                    dis = self.osmMapa.distance_to_string( self.osmMapa.distance( latc, lonc, c[4], c[5]) )
-
-                    mi = gtk.MenuItem("___________Distans it: %s" % dis)
-                    m.append(mi)
-
-                    mi = gtk.MenuItem("___________Center to")
-                    mi.connect("activate",self.on_set_center,c[4],c[5])
-                    m.append(mi)
-
-                    if CONFIG['POI']:
-                        mi = gtk.MenuItem("___________Add as POI")
-                        mi.connect("activate",self.on_add_as_poi,c[4],c[5])
+                    
+                    if type(c[6]) == list:
+                        self.on_details(None,c[6])
+                    
+                    """
+                    else:
+                        m = gtk.Menu()
+                        latc,lonc = self.osmMapa.get_may_current_ll()
+                        dis = self.osmMapa.distance_to_string( self.osmMapa.distance( latc, lonc, c[4], c[5]) )
+    
+                        mi = gtk.MenuItem("___________Distans it: %s" % dis)
                         m.append(mi)
-
-                    if CONFIG['Google - routesearch']:
-                        mi = gtk.MenuItem("___________Route to it")
-                        mi.connect("activate",self.on_route_to_it,c[4],c[5])
+    
+                        mi = gtk.MenuItem("___________Center to")
+                        mi.connect("activate",self.on_set_center,c[4],c[5])
                         m.append(mi)
-
-                    if type(c[6]) <> str:
-                        mi = gtk.MenuItem("___________Details")
-                        mi.connect("activate",self.on_details,c[6])
-                        m.append(mi)
-
-                    m.show_all()
-                    m.popup( None, None, None , 2, 0)
+    
+                        if CONFIG['POI']:
+                            mi = gtk.MenuItem("___________Add as POI")
+                            mi.connect("activate",self.on_add_as_poi,c[4],c[5])
+                            m.append(mi)
+    
+                        if CONFIG['Google - routesearch']:
+                            mi = gtk.MenuItem("___________Route to it")
+                            mi.connect("activate",self.on_route_to_it,c[4],c[5])
+                            m.append(mi)
+                            
+                        if type(c[6]) == list:
+                            mi = gtk.MenuItem("___________Details")
+                            mi.connect("activate",self.on_details,c[6])
+                            m.append(mi)
+    
+                        m.show_all()
+                        m.popup( None, None, None , 2, 0)
+                    """
 
         if timing_osd:
             print "YosmapaOSD press in:",( time.time()-t )
         return False
 
     def on_details(self, w, point):
-        w = DetailsWindow( self.osmMapa, point )
-
-
+        w = DetailsWindow( self.osmMapa, point, CONFIG )
+        
+    """
     def on_route_to_it(self, w, lat, lon):
         p = None
         for plugin in self.osmMapa.plugins_list:
@@ -387,6 +409,7 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
 
     def on_set_center(self, w,lat, lon):
         self.osmMapa.osm.set_center_and_zoom( lat,lon, 16)
+    """
 gobject.type_register(YosmapaOSD)
 
 
@@ -426,6 +449,27 @@ class UI(gtk.Window):
             self.fullscreen()
             self.window_is_fullscreen = True
 
+    def get_config(self):
+        return CONFIG
+
+    def set_autorotate_for_object_same_as_UI(self, obj):
+        try:
+            mode = self.window_rotate.get_mode()
+            print "mode --- ",mode
+            w = FremantleRotation(name, obj, version, mode)
+        except Exception, e:
+            print "mode set error :/ --------------- [",e,"]------------"
+            pass
+
+    def set_autorotate_for_object(self, obj):
+        if autorotate:
+            if CONFIG['autorotate']:
+                initial_mode = FremantleRotation.AUTOMATIC
+            else:
+                initial_mode = FremantleRotation.NEVER
+            self.window_rotate = FremantleRotation(name, obj, version, initial_mode)
+            print "__init__ autorotate init!"
+
     def on_key_down(self,widget,a):
         print "keydown", a.keyval
         if a.keyval == 102: # f
@@ -497,17 +541,13 @@ class UI(gtk.Window):
         self.baner_tmp = 0,0,""
 
         self.clikable_clouds = []
+        self.clikable_icons = []
+        self.cliked_item = []
 
         self.markers = []
 
-
-        if autorotate:
-            if CONFIG['autorotate']:
-                initial_mode = FremantleRotation.AUTOMATIC
-            else:
-                initial_mode = FremantleRotation.NEVER
-            self.window_rotate = FremantleRotation(name, self, version, initial_mode)
-            print "__init__ autorotate init!"
+        self.window_rotate = -1
+        self.set_autorotate_for_object(self)
 
 
         try:
@@ -625,22 +665,37 @@ class UI(gtk.Window):
         else:
             make_from = self.markers
 
-        icons_on_screen = 0
+        self.clikable_icons = []
+        if len(self.cliked_item) == 2:
+            icon_clicked = 1
+            #print "icon_clicked !",self.cliked_item
+        else:
+            icon_clicked = 0
+            
         for m in make_from:
             lt = m[0]
             ln = m[1]
             if m[6] < zoom and t_ln < ln and b_ln > ln and t_lt > lt and b_lt < lt:
+                x,y = self.osm.geographic_to_screen(lt,ln)
+                xoff, yoff = m[4].get_width(), m[4].get_height()
+                x-= xoff/2
+                y-= yoff/2
+                self.clikable_icons.append( [x, y, x+xoff, y+yoff, m] )
+
                 if not m[5]:
                     m[5] = self.osm.image_add( lt, ln, m[4] )
-                if zoom>10 and m[3]:
-                    if icons_on_screen < 8:
-                        icons_on_screen+=1
+
+
+                if m[2] == "Google - routesearch" and m[3]:
+                    self.draw_cloud_byll(cr, m)
+                elif ( m[3] and icon_clicked ):
+                    if self.cliked_item[0] == m[0] and self.cliked_item[1] == m[1]:
                         self.draw_cloud_byll(cr, m)
             else:
                 if m[5]:
                     self.osm.image_remove(m[5])
                     m[5] = None
-
+        
 
     def marker_clear_from_layer(self, from_what):
         for m in from_what:
@@ -774,19 +829,19 @@ class UI(gtk.Window):
             dis = self.distance_to_string( self.distance( latc, lonc, lat, lon) )
             cr.show_text("%s"%dis)
 
-    def draw_cloud_byll(self, cr, lat, lon = "", str = "", font_size = 13, Fifek = True):
-        if lon == "" and str == "":
+    def draw_cloud_byll(self, cr, lat, lon = None, str = None, font_size = 13, Fifek = True):
+        if lon == None and str == None:
             x,y = self.osm.geographic_to_screen(lat[0],lat[1])
             str = lat
         self.draw_cloud(cr, x, y, str, font_size, Fifek)
-    def draw_cloud(self, cr, x, y, str, font_size = 13, Fifek = True):
+    def draw_cloud(self, cr, x, y, str = None, font_size = 13, Fifek = True):
 
         point = None
-        if type(str) <> str:
+        if type(str) == list:
             point = str
             str = point[3]
-
-        if str == "":
+            
+        if str == "" or str == None:
             return None
         if x<0:
             print "inwert"
